/**
 * Color object
 *
 * @public
 */
export declare interface ColorObject {
    color: number;
    ratio?: number | undefined;
}

/**
 * common map param type
 *
 * @public
 */
export declare interface CommonMapParams {
    [key: string]: any;
}

/**
 * Convert the angle value of a string to an angle value
 *
 * @param value - target value
 * @param unit - unit type
 *
 * @public
 */
export declare function convertToDegree(value: string, unit?: string): string;

declare type CssAttribute = CommonMapParams;

/**
 * css node declaration type
 *
 * @public
 */
export declare interface CssDeclarationType {
    type: string;
    property: string;
    value: string | number;
}

/**
 * CSS node
 *
 * @public
 */
export declare interface CssNode {
    [key: string]: NeedToTyped_2;
}

/**
 * CSS AST type
 *
 * @public
 */
export declare interface CssNodeType {
    type: string;
    selectors: string[];
    declarations: CssDeclarationType[];
}

/**
 * parse css options
 *
 * @public
 */
export declare interface CssParserOption {
    source: number;
    silent?: boolean;
}

export declare const DEGREE_UNIT: {
    TURN: string;
    RAD: string;
    DEG: string;
};

declare interface DocSelector {
    sel: SelectorCore;
    pos: number;
}

/**
 * get css map
 *
 * @param styles - style list
 * @param beforeLoadStyle - before load style hook
 * @public
 */
export declare function getCssMap(styles?: any[], beforeLoadStyle?: Function): SelectorsMap;

/**
 * Get the angle value of the linear gradient
 *
 * @param value - target value
 *
 * @public
 */
export declare function getLinearGradientAngle(value: string): string;

/**
 * Get the color value of the linear gradient when it stops
 *
 * @param value - color
 *
 * @public
 */
export declare function getLinearGradientColorStop(value?: string): ColorObject | null;

/**
 * need delete style list, when we used hmr, expired style will be push to globally dispose array
 *
 * @public
 */
export declare const HIPPY_GLOBAL_DISPOSE_STYLE_NAME = "__HIPPY_VUE_DISPOSE_STYLES__";

/**
 * global style name
 *
 * @public
 */
export declare const HIPPY_GLOBAL_STYLE_NAME = "__HIPPY_VUE_STYLES__";

/**
 * insert style for ssr nodes
 *
 * @param nodeList - ssr node list
 * @param styleContent - style content
 *
 * @public
 */
export declare function insertStyleForSsrNodes(nodeList: StyleNode[], styleContent: NeedToTyped[]): StyleNode[];

/**
 * @public
 */
export declare type NeedToTyped = any;

declare type NeedToTyped_2 = any;

/**
 * parse background image style attribute
 *
 * @param property - property name
 * @param value - property value
 *
 * @public
 */
export declare function parseBackgroundImage(property: string, value: NeedToTyped_2): [string, NeedToTyped_2];

/**
 * parse css code into AST tree
 *
 * @param css - css code
 * @param options - parse options
 *
 * @public
 */
export declare function parseCSS(css: string, options?: CssParserOption): CssNode;

/**
 * properties map
 *
 * @public
 */
export declare const PROPERTIES_MAP: {
    textDecoration: string;
    boxShadowOffset: string;
    boxShadowOffsetX: string;
    boxShadowOffsetY: string;
    boxShadowOpacity: string;
    boxShadowRadius: string;
    boxShadowSpread: string;
    boxShadowColor: string;
};

/**
 * @public
 */
export declare interface PropertiesMapType {
    textDecoration: 'string';
    boxShadowOffset: 'string';
    boxShadowOffsetX: 'string';
    boxShadowOffsetY: 'string';
    boxShadowOpacity: 'string';
    boxShadowRadius: 'string';
    boxShadowSpread: 'string';
    boxShadowColor: 'string';
}

/**
 * Rule Set
 */
declare class RuleSet {
    selectors: SelectorCore[];
    declarations: CssDeclarationType[];
    hash: string;
    constructor(selectors: RuleSetSelector[], declarations: CssDeclarationType[], hash: string);
    toString(): string;
    lookupSort(sorter: SelectorsMap): void;
    removeSort(sorter: SelectorsMap): void;
}

declare type RuleSetSelector = SelectorCore & {
    ruleSet: RuleSet;
};

/**
 * Base classes
 */
declare class SelectorCore {
    dynamic?: boolean;
    specificity: number;
    ruleSet?: RuleSet;
    /**
     * Sort and store style rules according to categories,
     * such as id selectors are grouped into one category, class names are grouped into one category, etc.
     *
     * @param sorter - sort rules
     * @param base - base
     */
    lookupSort(sorter: SelectorsMap, base?: SelectorCore): void;
    /**
     * remove sort
     *
     * @param sorter - sort rules
     * @param base - base
     */
    removeSort(sorter: SelectorsMap, base?: SelectorCore): void;
}

/**
 * selectors map class
 *
 * @public
 *
 */
export declare class SelectorsMap {
    /**
     * Remove the specified style from the style rules map
     *
     * @param map - style map
     * @param head - style key
     * @param sel - selector
     */
    static removeFromMap(map: CssAttribute, head: string, sel: SelectorCore): void;
    id: CssAttribute;
    class: CssAttribute;
    type: CssAttribute;
    universal: DocSelector[];
    position: number;
    ruleSets: RuleSet[];
    constructor(ruleSets: RuleSet[]);
    /**
     * Append a new list of style rules
     *
     * @param appendRules - list of style rules
     */
    append(appendRules: RuleSet[]): void;
    /**
     * Find the style in the list of style rules according to the hash value and delete it
     *
     * @param hash - hash of style chunk
     */
    delete(hash: string): void;
    /**
     * Find the matching style information according to the id, class, attribute of the hippy node
     *
     * @param node - target node
     * @param ssrNodes - ssr node list
     */
    query(node: StyleNode, ssrNodes?: StyleNodeList): SelectorsMatch;
    removeById(id: string, sel: SelectorCore): void;
    sortById(id: string, sel: SelectorCore): void;
    removeByClass(cssClass: string, sel: SelectorCore): void;
    sortByClass(cssClass: string, sel: SelectorCore): void;
    removeByType(cssType: string, sel: SelectorCore): void;
    sortByType(cssType: string, sel: SelectorCore): void;
    removeAsUniversal(sel: SelectorCore): void;
    sortAsUniversal(sel: SelectorCore): void;
    /**
     * add style selector to map
     *
     * @param map - style map
     * @param head - style key
     * @param sel - selector
     */
    addToMap(map: CssAttribute, head: string, sel: SelectorCore): void;
    makeDocSelector(sel: SelectorCore): DocSelector;
}

/**
 * stores the Selector list matched by the node
 */
declare class SelectorsMatch {
    changeMap: any;
    selectors: any;
    constructor();
    /**
     * Add attribute
     *
     * @param node - target node
     * @param attribute - attribute name
     */
    addAttribute(node: StyleNode, attribute: any): void;
    /**
     * add pseudo class
     *
     * @param node - target node
     * @param pseudoClass - pseudo class
     */
    addPseudoClass(node: StyleNode, pseudoClass: string): void;
    properties(node: StyleNode): CommonMapParams;
}

/**
 * style node type
 *
 * @public
 */
export declare interface StyleNode {
    id: string;
    pId?: number;
    name?: string;
    tagName: string;
    classList: Set<string>;
    parentNode: StyleNode;
    nextSibling: StyleNode;
    props?: any;
    attributes?: any;
}

/**
 * style node list
 *
 * @public
 */
export declare interface StyleNodeList {
    [key: string]: StyleNode;
}

/**
 * Convert css color value or string description to native supported color format
 *
 * @param color - color value or string description
 *
 * @public
 */
export declare function translateColor(color: string | number): number;

export { }
